@@ -4,7 +4,7 @@ require 'spec_helper'
 require 'msf/core/auxiliary/cisco'
 
 RSpec.describe Msf::Auxiliary::Cisco do
-  class DummyClass
+  class DummyCiscoClass
     include Msf::Auxiliary::Cisco
     def framework
       Msf::Simple::Framework.create(
@@ -29,25 +29,25 @@ RSpec.describe Msf::Auxiliary::Cisco do
       raise StandardError.new("This method needs to be stubbed.")
     end
   end
-  
-  subject(:aux_cisco) { DummyClass.new }
-  
+
+  subject(:aux_cisco) { DummyCiscoClass.new }
+
   let!(:workspace) { FactoryBot.create(:mdm_workspace) }
-    
+
   context '#create_credential_and_login' do
-    
+
     let(:session) { FactoryBot.create(:mdm_session) }
 
     let(:task) { FactoryBot.create(:mdm_task, workspace: workspace)}
 
     let(:user) { FactoryBot.create(:mdm_user)}
 
-    subject(:test_object) { DummyClass.new }
-    
+    subject(:test_object) { DummyCiscoClass.new }
+
     let(:workspace) { FactoryBot.create(:mdm_workspace) }
     let(:service) { FactoryBot.create(:mdm_service, host: FactoryBot.create(:mdm_host, workspace: workspace)) }
     let(:task) { FactoryBot.create(:mdm_task, workspace: workspace) }
-    
+
     let(:login_data) {
       {
         address: service.host.address,
@@ -65,7 +65,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         status: Metasploit::Model::Login::Status::UNTRIED
       }
     }
-    
+
     it 'creates a Metasploit::Credential::Login' do
       expect{test_object.create_credential_and_login(login_data)}.to change{Metasploit::Credential::Login.count}.by(1)
     end
@@ -74,12 +74,12 @@ RSpec.describe Msf::Auxiliary::Cisco do
       expect(login.tasks).to include(task)
     end
   end
-  
+
   context '#cisco_ios_config_eater' do
     before(:example) do
       expect(aux_cisco).to receive(:myworkspace).at_least(:once).and_return(workspace)
     end
-    
+
     it 'deals with udp ports' do
       expect(aux_cisco).to receive(:print_good).with('127.0.0.1:161 Unencrypted Enable Password: 1511021F0725')
       expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -102,9 +102,9 @@ RSpec.describe Msf::Auxiliary::Cisco do
       )
       aux_cisco.cisco_ios_config_eater('127.0.0.1',161,'enable password 1511021F0725')
     end
-    
+
     context 'Enable Password|Secret' do
-      
+
       it 'with password type 0' do
         expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 Enable Password: 1511021F0725')
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -128,10 +128,10 @@ RSpec.describe Msf::Auxiliary::Cisco do
             status: Metasploit::Model::Login::Status::UNTRIED
           }
         )
-        
+
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'enable password 0 1511021F0725')
       end
-      
+
       it 'with password type 5' do
         expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 MD5 Encrypted Enable Password: 1511021F0725')
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -152,7 +152,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         )
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'enable password 5 1511021F0725')
       end
-      
+
       it 'with password type 7' do
         expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 Decrypted Enable Password: cisco')
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -178,9 +178,9 @@ RSpec.describe Msf::Auxiliary::Cisco do
         )
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'enable password 7 1511021F0725')
       end
-      
+
     end
-    
+
     it 'enable password' do
       expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 Unencrypted Enable Password: 1511021F0725')
       expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -203,9 +203,9 @@ RSpec.describe Msf::Auxiliary::Cisco do
       )
       aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'enable password 1511021F0725')
     end
-    
+
     context 'snmp-server community' do
-      
+
       it 'with RO' do
         expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 SNMP Community (RO): 1511021F0725')
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -226,7 +226,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         )
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'snmp-server community 1511021F0725 RO')
       end
-      
+
       it 'with RW' do
         expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 SNMP Community (RW): 1511021F0725')
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -247,9 +247,9 @@ RSpec.describe Msf::Auxiliary::Cisco do
         )
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'snmp-server community 1511021F0725 RW')
       end
-      
+
     end
-    
+
     it 'password 7' do
       expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 Decrypted VTY Password: cisco')
       expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -272,7 +272,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
       )
       aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'password 7 1511021F0725')
     end
-    
+
     it 'password|secret 5' do
       expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 MD5 Encrypted VTY Password: 1511021F0725')
       expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -299,7 +299,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
       )
       aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'password 5 1511021F0725')
     end
-    
+
     it 'password 0' do
       expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 Unencrypted VTY Password: 1511021F0725')
       expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -322,7 +322,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
       )
       aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'password 0 1511021F0725')
     end
-    
+
     it 'password' do
       expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 Unencrypted VTY Password: 1511021F0725')
       expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -345,7 +345,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
       )
       aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'password 1511021F0725')
     end
-    
+
     it 'encryption key' do
       expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 Wireless WEP Key: 1511021F0725')
       expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -357,7 +357,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
       )
       aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'encryption key 777 size 8bit 8 1511021F0725')
     end
-    
+
     context 'wpa-psk' do
       it 'with password type 0' do
         expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 Wireless WPA-PSK Password: 1511021F0725')
@@ -384,7 +384,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         )
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'wpa-psk ascii 0 1511021F0725')
       end
-      
+
       it 'with password type 5' do
         expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 Wireless WPA-PSK MD5 Password Hash: 1511021F0725')
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -411,7 +411,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         )
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'wpa-psk ascii 5 1511021F0725')
       end
-      
+
       it 'with password type 7' do
         expect(aux_cisco).to receive(:print_good).with('127.0.0.1:1337 Wireless WPA-PSK Decrypted Password: cisco')
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -435,12 +435,12 @@ RSpec.describe Msf::Auxiliary::Cisco do
             status: Metasploit::Model::Login::Status::UNTRIED
           }
         )
-        
+
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'wpa-psk ascii 7 1511021F0725')
       end
-            
+
     end
-    
+
     it 'crypto isakmp key' do
       expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 VPN IPSEC ISAKMP Key '1511021F0725' Host 'someaddress'")
       expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -466,7 +466,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
       )
       aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'crypto isakmp key 1511021F0725 address someaddress')
     end
-    
+
     it 'interface tunnel' do
       expect(aux_cisco).to receive(:store_loot).with(
         "cisco.ios.config", "text/plain", "127.0.0.1",  "interface tunnel7", "config.txt", "Cisco IOS Configuration"
@@ -475,7 +475,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
 
       aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'interface tunnel7')
     end
-    
+
     it 'tunnel key' do
       expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 GRE Tunnel Key 1511021F0725 for Interface Tunnel ")
       expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -501,7 +501,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
       )
       aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'tunnel key 1511021F0725')
     end
-    
+
     it 'ip nhrp authentication' do
       expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 NHRP Authentication Key 1511021F0725 for Interface Tunnel ")
       expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -527,7 +527,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
       )
       aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'ip nhrp authentication 1511021F0725')
     end
-    
+
     context 'username privilege secret' do
       it 'with password type 0' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 Username 'someusername' with Password: 1511021F0725")
@@ -556,7 +556,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
 
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'username someusername privilege 0 secret 0 1511021F0725')
       end
-      
+
       it 'with password type 5' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 Username 'someusername' with MD5 Encrypted Password: 1511021F0725")
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -586,7 +586,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'username someusername privilege 0 secret 5 1511021F0725')
       end
 
-    
+
       it 'with password type 7' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 Username 'someusername' with Decrypted Password: cisco")
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -614,7 +614,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'username someusername privilege 0 secret 7 1511021F0725')
       end
     end
-    
+
     context 'username secret' do
       it 'with password type 0' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 Username 'someusername' with Password: 1511021F0725")
@@ -643,7 +643,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         )
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'username someusername secret 0 1511021F0725')
       end
-      
+
       it 'with password type 5' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 Username 'someusername' with MD5 Encrypted Password: 1511021F0725")
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -673,7 +673,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'username someusername secret 5 1511021F0725')
       end
 
-    
+
       it 'with password type 7' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 Username 'someusername' with Decrypted Password: cisco")
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -702,7 +702,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'username someusername secret 7 1511021F0725')
       end
     end
-    
+
     context 'ppp.*username secret' do
       it 'with password type 0' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 PPP Username: someusername Password: 1511021F0725")
@@ -731,7 +731,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         )
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'ppp123username someusername secret 0 1511021F0725')
       end
-      
+
       it 'with password type 5' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 PPP Username someusername MD5 Encrypted Password: 1511021F0725")
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -761,7 +761,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'ppp123username someusername secret 5 1511021F0725')
       end
 
-    
+
       it 'with password type 7' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 PPP Username: someusername Decrypted Password: cisco")
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -790,7 +790,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'ppp123username someusername secret 7 1511021F0725')
       end
     end
-    
+
     context 'ppp chap secret' do
       it 'with password type 0' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 Password: 1511021F0725")
@@ -817,7 +817,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         )
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'ppp chap secret 0 1511021F0725')
       end
-      
+
       it 'with password type 5' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 PPP CHAP MD5 Encrypted Password: 1511021F0725")
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -846,7 +846,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'ppp chap secret 5 1511021F0725')
       end
 
-    
+
       it 'with password type 7' do
         expect(aux_cisco).to receive(:print_good).with("127.0.0.1:1337 PPP Decrypted Password: cisco")
         expect(aux_cisco).to receive(:report_host).with({:host => '127.0.0.1', :os_name => 'Cisco IOS'})
@@ -873,7 +873,7 @@ RSpec.describe Msf::Auxiliary::Cisco do
         aux_cisco.cisco_ios_config_eater('127.0.0.1',1337,'ppp chap secret 7 1511021F0725')
       end
     end
-    
+
   end
-  
+
 end
